from typing import get_type_hints, TypeVar

# https://docs.soliditylang.org/en/v0.8.13/abi-spec.html#types
int24 = TypeVar("int24")
...
int256 = TypeVar("int256")

uint8 = TypeVar("uint8")
uint16 = TypeVar("uint16")
uint24 = TypeVar("uint24")
uint32 = TypeVar("uint32")
uint40 = TypeVar("uint40")
uint48 = TypeVar("uint48")
uint56 = TypeVar("uint56")
uint64 = TypeVar("uint64")
uint72 = TypeVar("uint72")
uint80 = TypeVar("uint80")
uint88 = TypeVar("uint88")
uint96 = TypeVar("uint96")
uint104 = TypeVar("uint104")
uint112 = TypeVar("uint112")
uint120 = TypeVar("uint120")
uint128 = TypeVar("uint128")
uint136 = TypeVar("uint136")
uint144 = TypeVar("uint144")
uint152 = TypeVar("uint152")
uint160 = TypeVar("uint160")
uint168 = TypeVar("uint168")
uint176 = TypeVar("uint176")
uint184 = TypeVar("uint184")
uint192 = TypeVar("uint192")
uint200 = TypeVar("uint200")
uint208 = TypeVar("uint208")
uint216 = TypeVar("uint216")
uint224 = TypeVar("uint224")
...
uint256 = TypeVar("uint256")
uint = uint256

address = TypeVar("address")
string = TypeVar("string")
bool = TypeVar("bool")
